All Classes and Interfaces
Class
Description
Access was denied for this action.
An AWS Arn.
There was a conflict with this action, and it could not be completed.
CreateEndpointRequest MarshallerDeleteEndpointRequest Marshaller
Amazon S3 on Outposts Access Points simplify managing data access at scale for shared datasets in S3 on Outposts.
Link between an endpoint property and the
AwsEndpointAttribute it represents.
The failure reason, if any, for a create or delete endpoint operation.
Identifiers for variables declared within the rule engine, e.g.
There was an exception with the internal server.
Represents the output for the
S3OutpostsClient.listEndpointsPaginator(software.amazon.awssdk.services.s3outposts.model.ListEndpointsRequest)
operation which is a paginated operation.
Represents the output for the
S3OutpostsAsyncClient.listEndpointsPaginator(software.amazon.awssdk.services.s3outposts.model.ListEndpointsRequest)
operation which is a paginated operation.ListEndpointsRequest Marshaller
Represents the output for the
S3OutpostsClient.listOutpostsWithS3Paginator(software.amazon.awssdk.services.s3outposts.model.ListOutpostsWithS3Request)
operation which is a paginated operation.
Represents the output for the
S3OutpostsAsyncClient.listOutpostsWithS3Paginator(software.amazon.awssdk.services.s3outposts.model.ListOutpostsWithS3Request)
operation which is a paginated operation.ListOutpostsWithS3Request Marshaller
Represents the output for the
S3OutpostsClient.listSharedEndpointsPaginator(software.amazon.awssdk.services.s3outposts.model.ListSharedEndpointsRequest)
operation which is a paginated operation.
Represents the output for the
S3OutpostsAsyncClient.listSharedEndpointsPaginator(software.amazon.awssdk.services.s3outposts.model.ListSharedEndpointsRequest)
operation which is a paginated operation.ListSharedEndpointsRequest Marshaller
The container for the network interface.
Contains the details for the Outpost object.
The service link connection to your Outposts home Region is down.
The requested resource was not found.
Represents a URL to be used internally for endpoint resolution.
Service client for accessing Amazon S3 Outposts asynchronously.
A builder for creating an instance of
S3OutpostsAsyncClient.The parameters object used to resolve the auth schemes for the S3Outposts service.
A builder for a
S3OutpostsAuthSchemeParams.An auth scheme provider for S3Outposts service.
This includes configuration specific to Amazon S3 Outposts that is supported by both
S3OutpostsClientBuilder
and S3OutpostsAsyncClientBuilder.Service client for accessing Amazon S3 Outposts.
A builder for creating an instance of
S3OutpostsClient.The parameters object used to resolve an endpoint for the S3Outposts service.
An endpoint provider for S3Outposts.
Class to expose the service client settings to the user.
A builder for creating a
S3OutpostsServiceClientConfiguration
The request was denied due to request throttling.
There was an exception validating this data.
Base class for the types of values computable by the
RuleEngine.An array value.
A boolean value.
An integer value.
A record (map) value.
A string value.